==> haskell-http-types-0.12.4-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-types
version:              0.12.4
visibility:           public
id:                   http-types-0.12.4-KqSMzybuwrg29XllKzuhVg
key:                  http-types-0.12.4-KqSMzybuwrg29XllKzuhVg
license:              BSD-3-Clause
copyright:            (C) 2011 Aristid Breitkreuz
maintainer:           felix.paulusma@gmail.com
author:               Aristid Breitkreuz, Michael Snoyman
homepage:             https://github.com/Vlix/http-types
synopsis:
    Generic HTTP types for Haskell (for both client and server code).

description:
    Types and functions to describe and handle HTTP concepts.
    Including "methods", "headers", "query strings", "paths" and "HTTP versions".

category:             Network, Web
abi:                  9a69e0a2510a84e775bbe55fb26c3c82
exposed:              True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-types-0.12.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-types-0.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-types
hs-libraries:         HShttp-types-0.12.4-KqSMzybuwrg29XllKzuhVg
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-EnSgvsXdRX78Hz3HwummHY text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html:         /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.12.4-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-types
version:              0.12.4
visibility:           public
id:                   http-types-0.12.4-7BozLfTXeEWGYT0EKpPSnr
key:                  http-types-0.12.4-7BozLfTXeEWGYT0EKpPSnr
license:              BSD-3-Clause
copyright:            (C) 2011 Aristid Breitkreuz
maintainer:           felix.paulusma@gmail.com
author:               Aristid Breitkreuz, Michael Snoyman
homepage:             https://github.com/Vlix/http-types
synopsis:
    Generic HTTP types for Haskell (for both client and server code).

description:
    Types and functions to describe and handle HTTP concepts.
    Including "methods", "headers", "query strings", "paths" and "HTTP versions".

category:             Network, Web
abi:                  716ad3ff86a86be91dfb01719e1e4c59
exposed:              True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-types
hs-libraries:         HShttp-types-0.12.4-7BozLfTXeEWGYT0EKpPSnr
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4CWBjbNVYtn1DyQhk43ZQ9 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html:         /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
